@@ -1,3 +1,7 @@
+#if HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 /*
  * This file contains functions specific to ELF binaries
  */
