@@ -122,11 +122,11 @@ extern char * pid2name(pid_t pid);
 extern void trace_me(void);
 extern int trace_pid(pid_t pid);
 extern void untrace_pid(pid_t pid);
-extern void * get_instruction_pointer(int pid);
-extern void * get_stack_pointer(int pid);
-extern void * get_return_addr(int pid, void * stack_pointer);
-extern void insert_breakpoint(int pid, struct breakpoint * sbp);
-extern void delete_breakpoint(int pid, struct breakpoint * sbp);
+extern void * get_instruction_pointer(pid_t pid);
+extern void * get_stack_pointer(pid_t pid);
+extern void * get_return_addr(pid_t pid, void * stack_pointer);
+extern void insert_breakpoint(pid_t pid, struct breakpoint * sbp);
+extern void delete_breakpoint(pid_t pid, struct breakpoint * sbp);
 extern int fork_p(int sysnum);
 extern int exec_p(int sysnum);
 extern int syscall_p(struct process * proc, int status, int * sysnum);
